@@ -38,12 +38,13 @@
 #include "Command.h"
 #include "SharedHandle.h"
 #include "TimeA2.h"
+#include "FileEntry.h"
+#include "RequestGroup.h"
 
 namespace aria2 {
 
 class Request;
 class DownloadEngine;
-class RequestGroup;
 class Segment;
 class Exception;
 class SocketCore;
@@ -59,6 +60,7 @@ private:
 protected:
   RequestGroup* _requestGroup;
   SharedHandle<Request> req;
+  SharedHandle<FileEntry> _fileEntry;
   DownloadEngine* e;
   SharedHandle<SocketCore> socket;
   std::deque<SharedHandle<Segment> > _segments;
@@ -100,7 +102,16 @@ protected:
 
   void prepareForNextAction(Command* nextCommand = 0);
 
-  void checkIfConnectionEstablished(const SharedHandle<SocketCore>& socket);
+  // Check if socket is connected. If socket is not connected and
+  // there are other addresses to try, command is created using
+  // InitiateConnectionCommandFactory and it is pushed to
+  // DownloadEngine and returns false. If no addresses left, DlRetryEx
+  // exception is thrown.
+  bool checkIfConnectionEstablished
+  (const SharedHandle<SocketCore>& socket,
+   const std::string& connectedHostname,
+   const std::string& connectedAddr,
+   uint16_t connectedPort);
 
   /*
    * Returns true if proxy for the procol indicated by Request::getProtocol()
@@ -120,6 +131,11 @@ protected:
   const std::string& resolveProxyMethod(const std::string& protocol) const;
 
   const SharedHandle<Option>& getOption() const;
+
+  const SharedHandle<DownloadContext>& getDownloadContext() const
+  {
+    return _requestGroup->getDownloadContext();
+  }
 private:
   bool checkSocketIsReadable;
   bool checkSocketIsWritable;
@@ -137,6 +153,7 @@ private:
 #endif // ENABLE_ASYNC_DNS
 public:
   AbstractCommand(int32_t cuid, const SharedHandle<Request>& req,
+		  const SharedHandle<FileEntry>& fileEntry,
 		  RequestGroup* requestGroup, DownloadEngine* e,
 		  const SharedHandle<SocketCore>& s = SharedHandle<SocketCore>());
 
