@@ -55,7 +55,7 @@
 #include "DHTPeerAnnounceStorage.h"
 #include "DHTTokenTracker.h"
 #include "DHTMessageCallback.h"
-#include "PeerMessageUtil.h"
+#include "bittorrent_helper.h"
 #include "BtRuntime.h"
 #include "Util.h"
 #include "Peer.h"
@@ -332,7 +332,7 @@ DHTMessageFactoryImpl::extractNodes(const unsigned char* src, size_t length)
   for(size_t offset = 0; offset < length; offset += 26) {
     SharedHandle<DHTNode> node(new DHTNode(src+offset));
     std::pair<std::string, uint16_t> addr =
-      PeerMessageUtil::unpackcompact(src+offset+DHT_ID_LENGTH);
+      bittorrent::unpackcompact(src+offset+DHT_ID_LENGTH);
     if(addr.first.empty()) {
       continue;
     }
@@ -416,7 +416,7 @@ DHTMessageFactoryImpl::createGetPeersReplyMessageWithValues
     const BDE& data = *i;
     if(data.isString() && data.s().size() == 6) {
       std::pair<std::string, uint16_t> addr =
-	PeerMessageUtil::unpackcompact(data.uc());
+	bittorrent::unpackcompact(data.uc());
       PeerHandle peer(new Peer(addr.first, addr.second));
       peers.push_back(peer);
     }
