@@ -40,6 +40,7 @@
 #include "HttpServerCommand.h"
 #include "RequestGroupMan.h"
 #include "RecoverableException.h"
+#include "FileEntry.h"
 
 namespace aria2 {
 
@@ -53,7 +54,7 @@ HttpServerResponseCommand::HttpServerResponseCommand
   _socket(socket),
  _httpServer(httpServer)
 {
- 
+  setStatus(Command::STATUS_ONESHOT_REALTIME); 
   _e->addSocketForWriteCheck(_socket, this);
 }
 
