@@ -52,6 +52,9 @@
 #include "StringFormat.h"
 #include "A2STR.h"
 #include "Request.h"
+#include "a2functional.h"
+#include "message.h"
+#include "File.h"
 
 namespace aria2 {
 
@@ -126,7 +129,8 @@ public:
     } else if(optarg == "false") {
       option.put(_optName, V_FALSE);
     } else {
-      std::string msg = _optName+" "+_("must be either 'true' or 'false'.");
+      std::string msg = _optName;
+      strappend(msg, " ", _("must be either 'true' or 'false'."));
       throw DL_ABORT_EX(msg);
     }
   }
@@ -159,7 +163,8 @@ public:
     while(seq.hasNext()) {
       int32_t v = seq.next();
       if(v < _min || _max < v) {
-	std::string msg = _optName+" "+_("must be between %s and %s.");
+	std::string msg = _optName;
+	strappend(msg, " ", _("must be between %s and %s."));
 	throw DL_ABORT_EX
 	  (StringFormat(msg.c_str(), Util::itos(_min).c_str(),
 			Util::itos(_max).c_str()).str());
@@ -202,7 +207,8 @@ public:
     if((_min == -1 || _min <= number) && (_max ==  -1 || number <= _max)) {
       option.put(_optName, Util::itos(number));
     } else {
-      std::string msg = _optName+" ";
+      std::string msg = _optName;
+      msg += " ";
       if(_min == -1 && _max != -1) {
 	msg += StringFormat(_("must be smaller than or equal to %s."),
 			    Util::itos(_max).c_str()).str();
@@ -221,8 +227,19 @@ public:
 
   virtual std::string createPossibleValuesString() const
   {
-    return (_min == -1 ? "*" : Util::itos(_min))+"-"+
-      (_max == -1 ? "*" : Util::itos(_max));
+    std::string values;
+    if(_min == -1) {
+      values += "*";
+    } else {
+      values += Util::itos(_min);
+    }
+    values += "-";
+    if(_max == -1) {
+      values += "*";
+    } else {
+      values += Util::itos(_max);
+    }
+    return values;
   }
 };
 
@@ -268,7 +285,8 @@ public:
     if((_min < 0 || _min <= number) && (_max < 0 || number <= _max)) {
       option.put(_optName, optarg);
     } else {
-      std::string msg = _optName+" ";
+      std::string msg = _optName;
+      msg += " ";
       if(_min < 0 && _max >= 0) {
 	msg += StringFormat(_("must be smaller than or equal to %.1f."),
 			    _max).str();
@@ -358,7 +376,7 @@ public:
   virtual void parseArg(Option& option, const std::string& optarg)
   {
     std::string value = option.get(_optName);
-    value += optarg+_delim;
+    strappend(value, optarg, _delim);
     option.put(_optName, value);
   }
 
@@ -384,7 +402,7 @@ public:
     // See optarg is in the fomrat of "INDEX=PATH"
     Util::parseIndexPath(optarg);
     std::string value = option.get(_optName);
-    value += optarg+"\n";
+    strappend(value, optarg, "\n");
     option.put(_optName, value);
   }
 
@@ -453,13 +471,14 @@ public:
     std::deque<std::string>::const_iterator itr =
       std::find(_validParamValues.begin(), _validParamValues.end(), optarg);
     if(itr == _validParamValues.end()) {
-      std::string msg = _optName+" "+_("must be one of the following:");
+      std::string msg = _optName;
+      strappend(msg, " ", _("must be one of the following:"));
       if(_validParamValues.size() == 0) {
 	msg += "''";
       } else {
 	for(std::deque<std::string>::const_iterator itr = _validParamValues.begin();
 	    itr != _validParamValues.end(); ++itr) {
-	  msg += "'"+*itr+"' ";
+	  strappend(msg, "'", *itr, "' ");
 	}
       }
       throw DL_ABORT_EX(msg);
@@ -555,6 +574,32 @@ public:
   }
 };
 
+class LocalFilePathOptionHandler : public NameMatchOptionHandler {
+public:
+  LocalFilePathOptionHandler
+  (const std::string& optName,
+   const std::string& description = NO_DESCRIPTION,
+   const std::string& defaultValue = NO_DEFAULT_VALUE,
+   char shortName = 0):
+    NameMatchOptionHandler(optName, description, defaultValue,
+			   OptionHandler::REQ_ARG,
+			   shortName) {}
+
+  virtual void parseArg(Option& option, const std::string& optarg)
+  {
+    if(!File(optarg).isFile()) {
+      throw DL_ABORT_EX
+	(StringFormat(MSG_NOT_FILE, optarg.c_str()).str());
+    }
+    option.put(_optName, optarg);
+  }
+  
+  virtual std::string createPossibleValuesString() const
+  {
+    return "/path/to/file";
+  }
+};
+
 } // namespace aria2
 
 #endif // _D_OPTION_HANDLER_IMPL_H_
