@@ -174,8 +174,7 @@ downloadresultcode::RESULT main(int argc, char* argv[])
   SimpleRandomizer::init();
   BitfieldManFactory::setDefaultRandomizer(SimpleRandomizer::getInstance());
 #ifdef ENABLE_BITTORRENT
-  bittorrent::generateStaticPeerId(op->get(PREF_PEER_ID_PREFIX),
-				   SimpleRandomizer::getInstance());
+  bittorrent::generateStaticPeerId(op->get(PREF_PEER_ID_PREFIX));
 #endif // ENABLE_BITTORRENT
   if(op->get(PREF_LOG) == "-") {
     LogFactory::setLogFile(DEV_STDOUT);
