@@ -13,6 +13,7 @@
 #include "FileEntry.h"
 #include "array_fun.h"
 #include "messageDigest.h"
+#include "a2netcompat.h"
 
 namespace aria2 {
 
@@ -52,6 +53,8 @@ class BittorrentHelperTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testSetFileFilter_multi);
   CPPUNIT_TEST(testUTF8Torrent);
   CPPUNIT_TEST(testMetaData);
+  CPPUNIT_TEST(testCreatecompact);
+  CPPUNIT_TEST(testCheckBitfield);
   CPPUNIT_TEST_SUITE_END();
 public:
   void setUp() {
@@ -88,6 +91,8 @@ public:
   void testSetFileFilter_multi();
   void testUTF8Torrent();
   void testMetaData();
+  void testCreatecompact();
+  void testCheckBitfield();
 };
 
 
@@ -279,11 +284,9 @@ void BittorrentHelperTest::testGetInfoHashAsString() {
 }
 
 void BittorrentHelperTest::testGetPeerId() {
-  SharedHandle<DownloadContext> dctx(new DownloadContext());
-  CPPUNIT_ASSERT_EQUAL
-    (std::string("-aria-AAAAAAAAAAAAAA"),
-     generatePeerId("-aria-",
-		    SharedHandle<Randomizer>(new FixedNumberRandomizer())));
+  std::string peerId = generatePeerId("aria2-");
+  CPPUNIT_ASSERT(peerId.find("aria2-") == 0);
+  CPPUNIT_ASSERT_EQUAL((size_t)20, peerId.size());
 }
 
 void BittorrentHelperTest::testComputeFastSet()
@@ -643,6 +646,38 @@ void BittorrentHelperTest::testMetaData()
 		       dctx->getAttribute(BITTORRENT)[CREATION_DATE].i());
 }
 
+void BittorrentHelperTest::testCreatecompact()
+{
+  unsigned char compact[6];
+  // Note: bittorrent::createcompact() on linux can handle IPv4-mapped
+  // addresses like `ffff::127.0.0.1', but on cygwin, it doesn't.
+  CPPUNIT_ASSERT(createcompact(compact, "127.0.0.1", 6881));
+
+  std::pair<std::string, uint16_t> p = unpackcompact(compact);
+  CPPUNIT_ASSERT_EQUAL(std::string("127.0.0.1"), p.first);
+  CPPUNIT_ASSERT_EQUAL((uint16_t)6881, p.second);
+}
+
+void BittorrentHelperTest::testCheckBitfield()
+{
+  unsigned char bitfield[] = { 0xff, 0xe0 };
+  checkBitfield(bitfield, sizeof(bitfield), 11);
+  try {
+    checkBitfield(bitfield, sizeof(bitfield), 17);
+    CPPUNIT_FAIL("exception must be thrown.");
+  } catch(RecoverableException& e) {
+    // success
+  }
+  // Change last byte
+  bitfield[1] = 0xf0;
+  try {
+    checkBitfield(bitfield, sizeof(bitfield), 11);
+    CPPUNIT_FAIL("exception must be thrown.");
+  } catch(RecoverableException& e) {
+    // success
+  }
+}
+
 } // namespace bittorrent
 
 } // namespace aria2
