@@ -4,7 +4,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-#include "PeerMessageUtil.h"
+#include "bittorrent_helper.h"
 #include "MockBtMessage.h"
 #include "MockPieceStorage.h"
 #include "MockBtMessageFactory.h"
@@ -128,10 +128,10 @@ CPPUNIT_TEST_SUITE_REGISTRATION(BtRequestMessageTest);
 
 void BtRequestMessageTest::testCreate() {
   unsigned char msg[17];
-  PeerMessageUtil::createPeerMessageString(msg, sizeof(msg), 13, 6);
-  PeerMessageUtil::setIntParam(&msg[5], 12345);
-  PeerMessageUtil::setIntParam(&msg[9], 256);
-  PeerMessageUtil::setIntParam(&msg[13], 1024);
+  bittorrent::createPeerMessageString(msg, sizeof(msg), 13, 6);
+  bittorrent::setIntParam(&msg[5], 12345);
+  bittorrent::setIntParam(&msg[9], 256);
+  bittorrent::setIntParam(&msg[13], 1024);
   SharedHandle<BtRequestMessage> pm = BtRequestMessage::create(&msg[4], 13);
   CPPUNIT_ASSERT_EQUAL((uint8_t)6, pm->getId());
   CPPUNIT_ASSERT_EQUAL((size_t)12345, pm->getIndex());
@@ -141,7 +141,7 @@ void BtRequestMessageTest::testCreate() {
   // case: payload size is wrong
   try {
     unsigned char msg[18];
-    PeerMessageUtil::createPeerMessageString(msg, sizeof(msg), 14, 6);
+    bittorrent::createPeerMessageString(msg, sizeof(msg), 14, 6);
     BtRequestMessage::create(&msg[4], 14);
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(...) {
@@ -149,7 +149,7 @@ void BtRequestMessageTest::testCreate() {
   // case: id is wrong
   try {
     unsigned char msg[17];
-    PeerMessageUtil::createPeerMessageString(msg, sizeof(msg), 13, 7);
+    bittorrent::createPeerMessageString(msg, sizeof(msg), 13, 7);
     BtRequestMessage::create(&msg[4], 13);
     CPPUNIT_FAIL("exception must be thrown.");
   } catch(...) {
@@ -162,10 +162,10 @@ void BtRequestMessageTest::testGetMessage() {
   msg.setBegin(256);
   msg.setLength(1024);
   unsigned char data[17];
-  PeerMessageUtil::createPeerMessageString(data, sizeof(data), 13, 6);
-  PeerMessageUtil::setIntParam(&data[5], 12345);
-  PeerMessageUtil::setIntParam(&data[9], 256);
-  PeerMessageUtil::setIntParam(&data[13], 1024);
+  bittorrent::createPeerMessageString(data, sizeof(data), 13, 6);
+  bittorrent::setIntParam(&data[5], 12345);
+  bittorrent::setIntParam(&data[9], 256);
+  bittorrent::setIntParam(&data[13], 1024);
   CPPUNIT_ASSERT(memcmp(msg.getMessage(), data, 17) == 0);
 }
 
